@@ -1,13 +1,13 @@
 """
-Module for TFC/E SSH Keys endpoint.
+Module for TFC/E SSH Keys API endpoint.
 """
 
 
-class SSHKeys(object):
+class SSHKeys:
     """
     TFC/E SSH Keys methods.
     """
-    def __init__(self, client, **kwargs):
+    def __init__(self, client):
         self.client = client
 
     def list(self, page_number=None, page_size=None):
@@ -15,17 +15,17 @@ class SSHKeys(object):
         GET /organizations/:organization_name/ssh-keys
         """             
         base_url = '/'.join([self.client._base_uri_v2, 'organizations',
-                        self.client.org, 'ssh-keys'])
+            self.client.org, 'ssh-keys'])
 
-        return self.client._requestor.get(url=base_url, page_number=page_number,
-                                            page_size=page_size)
+        return self.client._requestor.get(url=base_url,
+            page_number=page_number, page_size=page_size)
 
     def show(self, id):
         """
         GET /ssh-keys/:ssh_key_id
         """
-        return self.client._requestor.get(url='/'.join([self.client._base_uri_v2,
-                                            'ssh-keys', id]))
+        return self.client._requestor.get(url='/'.join([
+            self.client._base_uri_v2, 'ssh-keys', id]))
 
     def create(self, name, value):
         """
